@@ -3,10 +3,11 @@
 # defining global variables more centrally
 utils::globalVariables(c(".data", "obs",
                          "from", "to", "name", "weight","sign","wave",
-                         "nodes","event","exposure",
+                         "nodes","edges","event","exposure",
                          "student","students","colleges",
                          "node","value","var","active","time",
                          "A","B","C","D",
+                         "type",
                          "n"))
 
 # Helper function for declaring available methods
@@ -38,6 +39,12 @@ seq_nodes <- function(.data){
   seq.int(net_nodes(.data))
 }
 
+interpolate <- function(values, positions, n, fill = NA) {
+  out <- rep(fill, n) 
+  out[positions] <- values
+  out
+}
+
 # #' @export
 # `%||%` <- function(x, y) {
 #   if (is_null(x)) y else x
